@@ -1,4 +1,4 @@
-/*	$Id: buffer.c,v 1.2 2004/09/12 08:11:40 steve Exp $	*/
+/*	$Id: buffer.c,v 1.3 2009/11/17 13:58:55 steve Exp $	*/
 
 /*-
  * Copyright (c) 2001 Steve C. Woodford.
@@ -46,7 +46,7 @@
 #define BUFFER_INIT_SIZE 128
 
 int
-buffer_init(struct buffer_ctx **bcp, int fd)
+buffer_init_delay(struct buffer_ctx **bcp, int fd, int txdelay)
 {
 	struct buffer_ctx *bc;
 
@@ -66,6 +66,7 @@ buffer_init(struct buffer_ctx **bcp, int fd)
 	bc->bc_buffhead = 0;
 	bc->bc_bufftail = 0;
 	bc->bc_fd = fd;
+	bc->bc_txdelay = txdelay;
 
 	*bcp = bc;
 	return (0);
@@ -78,6 +79,18 @@ buffer_destroy(struct buffer_ctx *bc)
 	(void) free(bc);
 }
 
+static ssize_t
+buffer_write(struct buffer_ctx *bc, const char *src, size_t bytes)
+{
+
+	if (bc->bc_txdelay && bytes) {
+		usleep(bc->bc_txdelay);
+		bytes = 1;
+	}
+
+	return (write(bc->bc_fd, src, bytes));
+}
+
 ssize_t
 buffer_fill(struct buffer_ctx *bc, const char *src, size_t bytes)
 {
@@ -90,7 +103,7 @@ buffer_fill(struct buffer_ctx *bc, const char *src, size_t bytes)
 	 * we can...
 	 */
 	if (bc->bc_bufflen == 0 || (rv = buffer_drain(bc) == 0)) {
-		if ((rv = write(bc->bc_fd, src, bytes)) == bytes)
+		if ((rv = buffer_write(bc, src, bytes)) == bytes)
 			return (0);
 		if (rv > 0) {
 			bytes -= rv;
@@ -182,7 +195,7 @@ buffer_drain(struct buffer_ctx *bc)
 
 	if (bc->bc_buffhead < bc->bc_bufftail) {
 		bytes = bc->bc_buffsize - bc->bc_bufftail;
-		written = write(bc->bc_fd, &bc->bc_buffp[bc->bc_bufftail],
+		written = buffer_write(bc, &bc->bc_buffp[bc->bc_bufftail],
 		    bytes);
 		if (written < bytes) {
 			if (written < 0) {
@@ -201,8 +214,8 @@ buffer_drain(struct buffer_ctx *bc)
 	if (bc->bc_bufftail < bc->bc_buffhead) {
 		bytes = bc->bc_buffhead - bc->bc_bufftail;
 
-		written = write(bc->bc_fd,
-		    &bc->bc_buffp[bc->bc_bufftail], bytes);
+		written = buffer_write(bc, &bc->bc_buffp[bc->bc_bufftail],
+		    bytes);
 		if (written < 0) {
 			if (errno != EAGAIN && errno != EINTR)
 				return (-1);
