@@ -1,4 +1,4 @@
-/*	$Id: client.c,v 1.6 2004/09/12 19:20:28 steve Exp $	*/
+/*	$Id: client.c,v 1.10 2010/03/01 22:37:04 steve Exp $	*/
 
 /*-
  * Copyright (c) 2001 Steve C. Woodford.
@@ -51,12 +51,17 @@ static const char *cf_client_opt_allowbreak(void *, char **, int, int, void *);
 static const char *cf_client_opt_suppressbanner(void *, char **, int, int,
 		    void *);
 static const char *cf_client_opt_timeout(void *, char **, int, int, void *);
+static const char *cf_client_opt_exclusive(void *, char **, int, int, void *);
+static const char *cf_client_opt_exclusive_timer(void *, char **, int, int,
+		    void *);
 
 static struct config_tokens cf_client_option_tokens[] = {
  {"readonly",		1, cf_client_opt_readonly},
  {"allowbreak",		1, cf_client_opt_allowbreak},
  {"timeout",		1, cf_client_opt_timeout},
  {"suppressbanner",	1, cf_client_opt_suppressbanner},
+ {"exclusive",		1, cf_client_opt_exclusive},
+ {"exclusive_timer",	1, cf_client_opt_exclusive_timer},
  {NULL, 0, NULL}
 };
 
@@ -72,9 +77,13 @@ client_init(struct client_ctx **ccp, struct client_ctx *pcc,
 
 	cc->cc_parent = pcc;
 	cc->cc_ops = cops;
-	if (copts)
+	if (copts) {
 		cc->cc_options = *copts;
+		if (!client_can_output(cc))
+			cc->cc_options.co_exclusive = CO_EXCLUSIVE_OVERRIDE;
+	}
 	cc->cc_fd = -1;
+	(void) gettimeofday(&cc->cc_in_stamp, NULL);
 
 	if (cops->co_init && (cops->co_init)(cc, carg) < 0) {
 		(void) free(cc);
@@ -160,3 +169,37 @@ cf_client_opt_suppressbanner(void *cs, char **argv, int argc, int cmpnd,
 
 	return (config_boolean(cs, argv[1], &co->co_suppressbanner));
 }
+
+/* ARGSUSED */
+static const char *
+cf_client_opt_exclusive(void *cs, char **argv, int argc, int cmpnd, void *arg)
+{
+	struct client_options *co = arg;
+	int x;
+
+	if (config_boolean(cs, argv[1], &x) == NULL) {
+		co->co_exclusive = x ? CO_EXCLUSIVE_ON : CO_EXCLUSIVE_OFF;
+		return (NULL);
+	}
+
+	if (strcasecmp(argv[1], "override") == 0) {
+		co->co_exclusive = CO_EXCLUSIVE_OVERRIDE;
+		return (NULL);
+	} else
+	if (strcasecmp(argv[1], "readonly") == 0) {
+		co->co_exclusive = CO_EXCLUSIVE_READONLY;
+		return (NULL);
+	}
+
+	return (config_err(cs, "Invalid 'exclusive' state"));
+}
+
+/* ARGSUSED */
+static const char *
+cf_client_opt_exclusive_timer(void *cs, char **argv, int argc, int cmpnd,
+    void *arg)
+{
+	struct client_options *co = arg;
+
+	return (config_integer(cs, argv[1], &co->co_exclusive_timer));
+}
