@@ -1,4 +1,4 @@
-/*	$Id: client.h,v 1.5 2004/09/12 19:20:28 steve Exp $	*/
+/*	$Id: client.h,v 1.10 2010/03/01 22:37:04 steve Exp $	*/
 
 /*-
  * Copyright (c) 2001 Steve C. Woodford.
@@ -33,6 +33,7 @@
 #define __client_h
 
 #include <sys/queue.h>
+#include <sys/time.h>
 #include "iocodes.h"
 
 struct client_ctx;
@@ -57,6 +58,12 @@ struct client_options {
 	int	co_allowbreak;
 	int	co_timeout;
 	int	co_suppressbanner;
+	int	co_exclusive;
+#define	CO_EXCLUSIVE_OFF	0
+#define	CO_EXCLUSIVE_ON		1
+#define	CO_EXCLUSIVE_OVERRIDE	2
+#define	CO_EXCLUSIVE_READONLY	3
+	int	co_exclusive_timer;
 };
 
 struct client_ctx {
@@ -69,7 +76,7 @@ struct client_ctx {
 	char			*cc_name;
 	void			*cc_data;
 	int			cc_fd;
-	int			cc_canhup;
+	struct timeval		cc_in_stamp;
 };
 TAILQ_HEAD(client_qhead, client_ctx);
 
