@@ -1,4 +1,4 @@
-/*	$Id: context.h,v 1.3 2003/12/11 11:55:06 steve Exp $	*/
+/*	$Id: context.h,v 1.4 2010/01/17 15:07:52 steve Exp $	*/
 
 /*-
  * Copyright (c) 2001 Steve C. Woodford.
@@ -42,6 +42,7 @@ struct context {
 	char			*c_name;
 	struct client_ctx	*c_server;
 	struct client_qhead	c_clients;
+	struct client_qhead	c_exclusive;
 	int			c_client_count;
 	int			c_total_clients;
 };
@@ -58,8 +59,9 @@ extern int	context_client_output(struct context *, const char *, size_t,
 		    struct client_ctx *);
 extern int	context_client_ioctl(struct context *, int, void *,
 		    struct client_ctx *);
+extern int	context_server_output(struct context *, const char *, size_t,
+		    struct client_ctx *);
 
-#define context_server_output(c,b,l,s)  client_output((c)->c_server,(b),(l),(s))
 #define context_server_ioctl(c,i,a,s)   client_ioctl((c)->c_server,(i),(a),(s))
 
 extern const char *cf_context_init(void *, char **, int, int, void *);
