@@ -1,4 +1,4 @@
-/*	$Id: listener.c,v 1.10 2004/12/06 20:34:56 steve Exp $	*/
+/*	$Id: listener.c,v 1.11 2009/11/16 14:30:13 steve Exp $	*/
 
 /*-
  * Copyright (c) 2001 Steve C. Woodford.
@@ -191,7 +191,8 @@ listener_destroy(struct client_ctx *cc)
 
 	if (lc->lc_args.la_address)
 		(void) free(lc->lc_args.la_address);
-	(void) free(lc->lc_args.la_port);
+	if (lc->lc_args.la_port)
+		(void) free(lc->lc_args.la_port);
 
 	(void) free(lc);
 }
@@ -351,6 +352,8 @@ cf_listener_init(void *cs, char **argv, int argc, int is_compound, void *arg)
 			(void) free(la.la_address);
 		if (la.la_port)
 			(void) free(la.la_port);
+		la.la_address = NULL;
+		la.la_port = NULL;
 	}
 
 	return (errstr);
@@ -362,6 +365,9 @@ cf_listener_address(void *cs, char **argv, int argc, int cmpnd, void *arg)
 {
 	struct listener_args *la = arg;
 
+	if (la->la_address != NULL)
+		return (config_err(cs, "listen address: already specified"));
+
 	if ((la->la_address = strdup(argv[1])) == NULL)
 		return (config_err(cs, "listen address: %s", strerror(errno)));
 
@@ -374,6 +380,9 @@ cf_listener_port(void *cs, char **argv, int argc, int cmpnd, void *arg)
 {
 	struct listener_args *la = arg;
 
+	if (la->la_port != NULL)
+		return (config_err(cs, "listen port: already specified"));
+
 	if ((la->la_port = strdup(argv[1])) == NULL)
 		return (config_err(cs, "listen port: %s", strerror(errno)));
 
